@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for workdocs service client paginators.
 
@@ -32,11 +33,12 @@ Usage::
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Iterator, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_workdocs.type_defs import (
     DescribeActivitiesResponseTypeDef,
     DescribeCommentsResponseTypeDef,
